Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(61)

Unified Diff: webkit/media/crypto/ppapi/content_decryption_module.h

Issue 11270057: Add type argument to pepper content decryptor method GenerateKeyRequest(). (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webkit/media/crypto/ppapi/content_decryption_module.h
diff --git a/webkit/media/crypto/ppapi/content_decryption_module.h b/webkit/media/crypto/ppapi/content_decryption_module.h
index aedf6d4538397567174fbbe4c36781d9380154ed..0a9637263e98f64ab13adf01ab6ee8edc8960b66 100644
--- a/webkit/media/crypto/ppapi/content_decryption_module.h
+++ b/webkit/media/crypto/ppapi/content_decryption_module.h
@@ -195,7 +195,7 @@ enum StreamType {
// when a Buffer is created that will never be returned to the caller.
class ContentDecryptionModule {
public:
// Generates a |key_request| given the |init_data|.
//
// Returns kSuccess if the key request was successfully generated,
// in which case the callee should have allocated memory for the output
@@ -203,11 +203,9 @@ class ContentDecryptionModule {
// to the caller.
// Returns kSessionError if any error happened, in which case the
// |key_request| should not be used by the caller.
- //
- // TODO(xhwang): It's not safe to pass the ownership of the dynamically
- // allocated memory over library boundaries. Fix it after related PPAPI change
- // and sample CDM are landed.
- virtual Status GenerateKeyRequest(const uint8_t* init_data,
+ virtual Status GenerateKeyRequest(const char* mime_type,
ddorwin 2012/10/26 18:37:06 I notice that we don't pass key_system in GKR(). T
Tom Finegan 2012/10/26 22:51:33 Done.
+ int mime_type_size,
+ const uint8_t* init_data,
int init_data_size,
KeyMessage* key_request) = 0;
@@ -195,7 +195,7 @@ enum StreamType {
class ContentDecryptionModule {
public:
- // Generates a |key_request| given the |init_data|.
+ // Generates a |key_request| given the |mime_type| and |init_data|.
//
// Returns kSuccess if the key request was successfully generated,

Powered by Google App Engine
This is Rietveld 408576698